@@ -15,3 +15,10 @@ then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/openmpi-totalview.tcl /etc/openmpi-totalview.tcl
 fi
+
+if [ ! -f /etc/pmix-mca-params.conf ]
+then
+    /usr/bin/mkdir -p /etc
+    /usr/bin/cp /etc/defaults/etc/pmix-mca-params.conf /etc/pmix-mca-params.conf
+fi
+
